sage_numerical_backends_coin: COIN-OR backend for Sage MixedIntegerLinearProgram
================================================================================

Description
-----------

COIN-OR backend for Sage MixedIntegerLinearProgram

License
-------

GPLv2+

Upstream Contact
----------------

https://pypi.org/project/passagemath-coin-or-cbc

